#pragma once
#include "Component.h"
#include "box2d/box2d.h"
#include <memory>

class PhysicsComponent : public Component {
public:
    enum class BodyType { Static, Dynamic, Kinematic };

    PhysicsComponent(Object* owner, BodyType type = BodyType::Dynamic, float width = 1.0f, float height = 1.0f);

    ~PhysicsComponent();

    void CreateBody(b2World* world, const glm::vec2& position);
    void DestroyBody();

    void SetVelocity(const glm::vec2& vel);
    glm::vec2 GetVelocity() const;

    void SetFriction(float friction);
    void SetDensity(float density);
    void SetFixedRotation(bool fixed);

    void SyncFromPhysics();
    void SyncToPhysics();

    void OnImGuiInspector() override;

private:
    b2Body* body = nullptr;
    b2World* world = nullptr;
    BodyType type;
    float width, height;
    float friction = 0.3f;
    float density = 1.0f;
    bool fixedRotation = false;
};
